@@ -1,5 +1,4 @@
 from octue.cloud.deployment.google.base_deployer import BaseDeployer, ProgressMessage
-from octue.cloud.pub_sub.service import OCTUE_NAMESPACE
 from octue.cloud.pub_sub.subscription import Subscription
 from octue.cloud.pub_sub.topic import Topic
 from octue.exceptions import DeploymentError
@@ -34,9 +33,7 @@ class CloudRunDeployer(BaseDeployer):
 
     def __init__(self, octue_configuration_path, image_uri_template=None):
         super().__init__(octue_configuration_path, image_uri_template)
-        self.build_trigger_description = (
-            f"Build the {self.service_configuration.name!r} service and deploy it to Cloud Run."
-        )
+        self.build_trigger_description = f"Build the {self.service_sruid!r} service and deploy it to Cloud Run."
 
     def deploy(self, no_cache=False, update=False):
         """Create a Google Cloud Build configuration from the `octue.yaml` file, create a build trigger, and run the
@@ -53,7 +50,7 @@ class CloudRunDeployer(BaseDeployer):
         self._create_eventarc_run_trigger(update=update)
 
         print(self.success_message)
-        return self.service_id
+        return self.service_sruid
 
     def _generate_cloud_build_configuration(self, no_cache=False):
         """Generate a Google Cloud Build configuration equivalent to a `cloudbuild.yaml` file in memory and assign it
@@ -134,7 +131,7 @@ class CloudRunDeployer(BaseDeployer):
                             "run",
                             "services",
                             "update",
-                            self.service_configuration.name,
+                            self.cloud_build_service_sruid,
                             "--platform=managed",
                             f"--image={self.image_uri_template}",
                             f"--region={self.service_configuration.region}",
@@ -166,7 +163,7 @@ class CloudRunDeployer(BaseDeployer):
                 "run",
                 "services",
                 "add-iam-policy-binding",
-                self.service_configuration.name,
+                self.cloud_build_service_sruid,
                 f"--region={self.service_configuration.region}",
                 "--member=allUsers",
                 "--role=roles/run.invoker",
@@ -187,11 +184,7 @@ class CloudRunDeployer(BaseDeployer):
             5,
             self.TOTAL_NUMBER_OF_STAGES,
         ) as progress_message:
-            topic = Topic(
-                name=self.service_id,
-                project_name=self.service_configuration.project_name,
-                namespace=OCTUE_NAMESPACE,
-            )
+            topic = Topic(name=self.pub_sub_service_sruid, project_name=self.service_configuration.project_name)
 
             topic.create(allow_existing=True)
 
@@ -202,9 +195,9 @@ class CloudRunDeployer(BaseDeployer):
                 "eventarc",
                 "triggers",
                 "create",
-                f"{self.service_configuration.name}-trigger",
+                f"{self.cloud_build_service_sruid}-trigger",
                 "--matching-criteria=type=google.cloud.pubsub.topic.v1.messagePublished",
-                f"--destination-run-service={self.service_configuration.name}",
+                f"--destination-run-service={self.cloud_build_service_sruid}",
                 f"--location={self.service_configuration.region}",
                 f"--transport-topic={topic.name}",
             ]
@@ -215,7 +208,7 @@ class CloudRunDeployer(BaseDeployer):
                 eventarc_subscription_path = None
 
                 for subscription_path in topic.get_subscriptions():
-                    if self.service_configuration.name in subscription_path:
+                    if self.pub_sub_service_sruid in subscription_path:
                         eventarc_subscription_path = subscription_path
                         break
 
