@@ -12,6 +12,7 @@ from octue.resources import Manifest
 logger = logging.getLogger(__name__)
 
 MESSAGES = {}
+SUBSCRIPTIONS = {}
 
 
 class MockTopic(Topic):
@@ -29,7 +30,7 @@ class MockTopic(Topic):
                 raise google.api_core.exceptions.AlreadyExists(f"Topic {self.path!r} already exists.")
 
         if not self.exists():
-            MESSAGES[get_service_id(self.path)] = []
+            MESSAGES[self.name] = []
             self._created = True
 
     def delete(self):
@@ -38,7 +39,7 @@ class MockTopic(Topic):
         :return None:
         """
         try:
-            del MESSAGES[get_service_id(self.path)]
+            del MESSAGES[self.name]
         except KeyError:
             pass
 
@@ -48,19 +49,29 @@ class MockTopic(Topic):
         :param float timeout:
         :return bool:
         """
-        return get_service_id(self.path) in MESSAGES
+        return self.name in MESSAGES
 
 
 class MockSubscription(Subscription):
     """A mock subscription that registers in a global dictionary rather than Google Pub/Sub."""
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._subscriber = MockSubscriber()
+
     def create(self, allow_existing=False):
-        """Do nothing.
+        """Register the subscription in the global subscriptions dictionary.
 
         :param bool allow_existing:
         :return None:
         """
-        self._created = True
+        if not allow_existing:
+            if self.exists():
+                raise google.api_core.exceptions.AlreadyExists(f"Subscription {self.path!r} already exists.")
+
+        if not self.exists():
+            SUBSCRIPTIONS[self.name] = []
+            self._created = True
 
     def delete(self):
         """Do nothing.
@@ -69,6 +80,14 @@ class MockSubscription(Subscription):
         """
         pass
 
+    def exists(self, timeout=5):
+        """Check if the subscription exists in the global subscriptions dictionary.
+
+        :param float timeout:
+        :return bool:
+        """
+        return self.name in SUBSCRIPTIONS
+
 
 class MockFuture:
     """A mock future that is returned when publishing or subscribing."""
@@ -241,6 +260,7 @@ class MockService(Service):
         service_id,
         input_values=None,
         input_manifest=None,
+        children=None,
         subscribe_to_logs=True,
         allow_local_files=False,
         allow_save_diagnostics_data_on_crash=True,
@@ -255,6 +275,7 @@ class MockService(Service):
         :param str service_id:
         :param dict|list|None input_values:
         :param octue.resources.manifest.Manifest|None input_manifest:
+        :param list(dict)|None children:
         :param bool subscribe_to_logs:
         :param bool allow_local_files:
         :param bool allow_save_diagnostics_data_on_crash:
@@ -267,6 +288,7 @@ class MockService(Service):
             service_id=service_id,
             input_values=input_values,
             input_manifest=input_manifest,
+            children=children,
             subscribe_to_logs=subscribe_to_logs,
             allow_local_files=allow_local_files,
             allow_save_diagnostics_data_on_crash=allow_save_diagnostics_data_on_crash,
@@ -283,7 +305,9 @@ class MockService(Service):
         try:
             self.children[service_id].answer(
                 MockMessage(
-                    data=json.dumps({"input_values": input_values, "input_manifest": input_manifest}).encode(),
+                    data=json.dumps(
+                        {"input_values": input_values, "input_manifest": input_manifest, "children": children}
+                    ).encode(),
                     question_uuid=question_uuid,
                     forward_logs=subscribe_to_logs,
                     octue_sdk_version=parent_sdk_version,
@@ -297,25 +321,29 @@ class MockService(Service):
 
 
 class MockMessagePuller:
-    """A mock message puller that returns the messages in the order they were provided on initialisation. This is meant
-    for patching `octue.cloud.pub_sub.message_handler.OrderedMessageHandler._pull_message` in tests.
+    """A mock message puller that enqueues messages in the message handler in the order they're provided on
+    initialisation. This is meant for patching
+    `octue.cloud.pub_sub.message_handler.OrderedMessageHandler._pull_and_enqueue_message` in tests.
 
     :param iter(dict) messages:
+    :param octue.cloud.pub_sub.message_handler.OrderedMessageHandler message_handler:
     :return None:
     """
 
-    def __init__(self, messages):
+    def __init__(self, messages, message_handler):
         self.messages = messages
+        self.message_handler = message_handler
         self.message_number = 0
 
     def pull(self, timeout, delivery_acknowledgement_timeout):
-        """Get the next message from the messages given at initialisation.
+        """Get the next message from the messages given at instantiation and enqueue it for handling in the message
+        handler.
 
-        :return dict:
+        :return None:
         """
         message = self.messages[self.message_number]
+        self.message_handler._waiting_messages[int(message["message_number"])] = message
         self.message_number += 1
-        return message
 
 
 class MockAnalysis:
