@@ -12,7 +12,7 @@ class ServiceConfiguration:
     """A class containing the details needed to configure a service.
 
     :param str name: the name to give the service
-    :param str|None organisation: the name of the organisation providing the service
+    :param str namespace: the namespace for grouping the service with others (e.g. the name of an organisation or individual)
     :param str app_source_path: the path to the directory containing the app's source code
     :param str twine_path: the path to the twine file defining the schema for input, output, and configuration data for the service
     :param str|None app_configuration_path: the path to the app configuration file containing configuration data for the service; if this is `None`, the default application configuration is used
@@ -23,7 +23,7 @@ class ServiceConfiguration:
     def __init__(
         self,
         name,
-        organisation=None,
+        namespace,
         app_source_path=".",
         twine_path="twine.json",
         app_configuration_path=None,
@@ -49,17 +49,12 @@ class ServiceConfiguration:
         **kwargs,
     ):
         self.name = name
-        self.organisation = organisation
+        self.namespace = namespace
         self.app_source_path = app_source_path
         self.twine_path = twine_path
         self.app_configuration_path = app_configuration_path
         self.crash_diagnostics_cloud_path = crash_diagnostics_cloud_path
 
-        if organisation:
-            self.service_id = organisation + "/" + name
-        else:
-            self.service_id = self.name
-
         # Deployed services only.
         self.repository_name = repository_name
         self.repository_owner = repository_owner
@@ -109,7 +104,7 @@ class AppConfiguration:
 
     :param str|dict|list|None configuration_values: values to configure the app
     :param str|dict|octue.resources.Manifest|None configuration_manifest: a manifest of datasets to configure the app
-    :param str|None|list children: details of the children the app requires
+    :param str|list(dict)|None children: details of the children the app requires
     :param str|None output_location: the path to a cloud directory to save output datasets at
     :return None:
     """
